@@ -60,7 +60,7 @@ def sanitize(text):
 
 
 def extract(html):
-    m = re.search(r'\n\tdata = (.+);\n\tpageIdx = 0;\n', html)
+    m = re.search(r'\s+data = (.+);\s*pageIdx = 0;', html)
     if m:
         for data in json.loads(m.group(1))[0]['errInfo']:
             input, output, help = data['orgStr'], data['candWord'], data['help']
